==> embrace-android-bug-shake-0.6.0-sources.jar: io/embrace/android/embracesdk/bugshake/EmbraceBugShakeActivity.kt <==
package io.embrace.android.embracesdk.bugshake

import android.app.AlertDialog
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.Menu
import android.view.MenuItem
import android.view.View
import android.widget.ArrayAdapter
import android.widget.Button
import android.widget.EditText
import android.widget.Spinner
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import io.embrace.android.embracesdk.Embrace
import io.embrace.android.embracesdk.Embrace.BugReportCategory
import io.embrace.android.embracesdk.R

internal class EmbraceBugShakeActivity : AppCompatActivity() {

    companion object {
        const val MAX_LENGTH = 220
    }

    private lateinit var categorySpinner: Spinner
    private lateinit var reportText: EditText
    private lateinit var categories: Map<String, BugReportCategory>

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setContentView(R.layout.embrace_shake_activity)

        try {
            if (supportActionBar == null) {
                setSupportActionBar(findViewById(R.id.embrace_bugshake_toolbar))
            }
            supportActionBar?.setTitle(R.string.embrace_bugshake_report_an_issue)
            supportActionBar?.setDisplayHomeAsUpEnabled(true)
            supportActionBar?.setHomeAsUpIndicator(android.R.drawable.ic_menu_close_clear_cancel)
        } catch (e: Exception) {
            val sendBtn : Button = findViewById(R.id.embrace_bugshake_send_btn)
            sendBtn.visibility = View.VISIBLE
            sendBtn.setOnClickListener { sendBugReport() }
        }

        categorySpinner = findViewById(R.id.shake_bug_category)
        fillSpinner()

        reportText = findViewById(R.id.embrace_bugshake_bug_report)
        val charCount: TextView = findViewById(R.id.embrace_bugshake_bug_char_count)
        charCount.text = getString(R.string.embrace_bugshake_report_characters, 0, MAX_LENGTH)
        reportText.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(p0: Editable?) {
                val length = reportText.text.toString().length
                if (length > MAX_LENGTH) {
                    reportText.setText(reportText.text.substring(MAX_LENGTH))
                }
                charCount.text = getString(R.string.embrace_bugshake_report_characters, length, MAX_LENGTH)
            }

            override fun beforeTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {
                // no op
            }

            override fun onTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {
                // no op
            }
        })
    }

    override fun onCreateOptionsMenu(menu: Menu?): Boolean {
        menuInflater.inflate(R.menu.embrace_shake_menu, menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        val id = item.itemId
        if (id == R.id.shake_send) {
            sendBugReport()
            return true
        } else if (id == android.R.id.home) {
            if (reportText.text.toString().isNotBlank()) {
                showCloseDialog()
            } else {
                finish()
            }
            return true
        }
        return super.onOptionsItemSelected(item)
    }

    private fun sendBugReport() {
        val category = categories[categorySpinner.selectedItem.toString()]
        category?.let {
            val report = reportText.text.toString()
            Embrace.getInstance().logBugReport(category, report)
            showSentDialog()
        }
    }

    private fun showSentDialog() {
        val dialogBuilder = AlertDialog.Builder(this)
        dialogBuilder
            .setMessage(getString(R.string.embrace_bugshake_sent))
            .setCancelable(true)
            .setPositiveButton(getString(R.string.embrace_bugshake_done)) { dialog, _ ->
                dialog.dismiss()
                finish()
            }
        dialogBuilder.create().show()
    }

    private fun showCloseDialog() {
        val dialogBuilder = AlertDialog.Builder(this)
        dialogBuilder
            .setMessage(getString(R.string.embrace_bugshake_close))
            .setNegativeButton(getString(android.R.string.cancel)) { dialog, _ -> dialog.dismiss() }
            .setPositiveButton(getString(android.R.string.ok)) { dialog, _ ->
                dialog.dismiss()
                finish()
            }
        dialogBuilder.create().show()
    }

    private fun fillSpinner() {
        categories = mapOf(
            getString(R.string.embrace_bugshake_category_bug) to BugReportCategory.BUG,
            getString(R.string.embrace_bugshake_category_question) to BugReportCategory.QUESTION,
            getString(R.string.embrace_bugshake_category_suggestion) to BugReportCategory.SUGGESTION,
            getString(R.string.embrace_bugshake_category_other) to BugReportCategory.OTHER,
        )
        ArrayAdapter(this, android.R.layout.simple_spinner_item, categories.keys.toTypedArray())
            .also { adapter ->
                adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
                categorySpinner.adapter = adapter
            }
    }
}

==> embrace-android-bug-shake-0.7.0-sources.jar: io/embrace/android/embracesdk/bugshake/EmbraceBugShakeActivity.kt <==
package io.embrace.android.embracesdk.bugshake

import android.app.Activity
import android.app.AlertDialog
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.View
import android.widget.ArrayAdapter
import android.widget.Button
import android.widget.EditText
import android.widget.Spinner
import android.widget.TextView
import io.embrace.android.embracesdk.Embrace
import io.embrace.android.embracesdk.Embrace.BugReportCategory
import io.embrace.android.embracesdk.R

internal class EmbraceBugShakeActivity : Activity() {

    companion object {
        const val MAX_LENGTH = 220
    }

    private lateinit var categorySpinner: Spinner
    private lateinit var reportText: EditText
    private lateinit var categories: Map<String, BugReportCategory>

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setContentView(R.layout.embrace_shake_activity)

        val sendBtn : Button = findViewById(R.id.embrace_bugshake_send_btn)
        sendBtn.visibility = View.VISIBLE
        sendBtn.setOnClickListener { sendBugReport() }

        categorySpinner = findViewById(R.id.shake_bug_category)
        fillSpinner()

        reportText = findViewById(R.id.embrace_bugshake_bug_report)
        val charCount: TextView = findViewById(R.id.embrace_bugshake_bug_char_count)
        charCount.text = getString(R.string.embrace_bugshake_report_characters, 0, MAX_LENGTH)
        reportText.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(p0: Editable?) {
                val length = reportText.text.toString().length
                if (length > MAX_LENGTH) {
                    reportText.setText(reportText.text.substring(MAX_LENGTH))
                }
                charCount.text = getString(R.string.embrace_bugshake_report_characters, length, MAX_LENGTH)
            }

            override fun beforeTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {
                // no op
            }

            override fun onTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {
                // no op
            }
        })
    }

    override fun onBackPressed() {
        if (reportText.text.isNotBlank()) {
            showCloseDialog()
        } else {
            super.onBackPressed()
        }
    }

    private fun sendBugReport() {
        val category = categories[categorySpinner.selectedItem.toString()]
        category?.let {
            val report = reportText.text.toString()
            Embrace.getInstance().logBugReport(category, report)
            showSentDialog()
        }
    }

    private fun showSentDialog() {
        val dialogBuilder = AlertDialog.Builder(this)
        dialogBuilder
            .setMessage(getString(R.string.embrace_bugshake_sent))
            .setCancelable(true)
            .setPositiveButton(getString(R.string.embrace_bugshake_done)) { dialog, _ ->
                dialog.dismiss()
                finish()
            }
        dialogBuilder.create().show()
    }

    private fun showCloseDialog() {
        val dialogBuilder = AlertDialog.Builder(this)
        dialogBuilder
            .setMessage(getString(R.string.embrace_bugshake_close))
            .setNegativeButton(getString(android.R.string.cancel)) { dialog, _ -> dialog.dismiss() }
            .setPositiveButton(getString(android.R.string.ok)) { dialog, _ ->
                dialog.dismiss()
                finish()
            }
        dialogBuilder.create().show()
    }

    private fun fillSpinner() {
        categories = mapOf(
            getString(R.string.embrace_bugshake_category_bug) to BugReportCategory.BUG,
            getString(R.string.embrace_bugshake_category_question) to BugReportCategory.QUESTION,
            getString(R.string.embrace_bugshake_category_suggestion) to BugReportCategory.SUGGESTION,
            getString(R.string.embrace_bugshake_category_other) to BugReportCategory.OTHER,
        )
        ArrayAdapter(this, android.R.layout.simple_spinner_item, categories.keys.toTypedArray())
            .also { adapter ->
                adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
                categorySpinner.adapter = adapter
            }
    }
}
